do_full_boxplot_RNA: create tcga boxplots

Description Usage Arguments

Description

Creates boxplots from prediction scores from pls or plsda Makes some boxplots

Creates boxplots from prediction scores from pls or plsda Makes some boxplots

Usage

1
2
3
4
5
6
7
do_full_boxplot_RNA(file_pattern, tcga_location, crpc_file, nepc_file,
  sclc_file, output_folder, comp.x = "comp.1", components = 3,
  threshold = 3)

do_full_boxplot_RNA(file_pattern, tcga_location, crpc_file, nepc_file,
  sclc_file, output_folder, comp.x = "comp.1", components = 3,
  threshold = 3)

Arguments

tcga_location

location of predicted files of tcga

crpc_file

location of predicted file of crpc

nepc_file

location of predicted file of nepc

sclc_file

location of predicted file of sclc

output_folder

the folder to output to, default is ./ i.e. current folder

pattern

pattern to grep for in files that have predictions

pattern

pattern to grep for in files that have predictions

tcga_location

location of predicted files of tcga

crpc_file

location of predicted file of crpc

nepc_file

location of predicted file of nepc

sclc_file

location of predicted file of sclc

output_folder

the folder to output to, default is ./ i.e. current folder


graeberlab/small.cell.project documentation built on May 12, 2019, 5:16 p.m.