predict_PLSR_graph: Predict all files in a folder using PLSR of a training...

Description Usage Arguments

Description

Predict all files in a folder using PLSR of a training dataset, file names have to be of form name_.......txt Predicts classifications of test dataset and writes out predictions

Usage

1
2
3
4
predict_PLSR_graph(prediction_file, test_files_folder, anno.file,
  output_folder = "./", train_string = "", test_pattern = "",
  train_pattern = "", comps = 3, varimax = F, varimax.comp = 2,
  shape.palette = NULL, colpalette = NULL)

Arguments

prediction_file

file with training data features rows , genes columns, features are in column 1

test_files_folder

folder of test files

anno.file

Annotation file, first column is sample names, 2nd is annotation

output_folder

output folder

train_string

string of training data to insert in file name of predicted scores

train_pattern

annotation type of main group in your comparison ,taken from 2nd column in anno.

comps

number of components to compute

varimax.comp

# of varimax comps , has to match # of comps

shape.palette

vector with numbers reprsenting shapes according to R plotting

test_string

string of data being tested to insert in file name of predicted scores

varimax.it

do you want to perform varimax , default varimax=F


graeberlab/small.cell.project documentation built on May 12, 2019, 5:16 p.m.