Creates boxplots from prediction scores from pls or plsda Makes some boxplots
Creates boxplots from prediction scores from pls or plsda Makes some boxplots
1 2 3 4 5 6 7 | do_full_boxplot_RNA(file_pattern, tcga_location, crpc_file, nepc_file,
sclc_file, output_folder, comp.x = "comp.1", components = 3,
threshold = 3)
do_full_boxplot_RNA(file_pattern, tcga_location, crpc_file, nepc_file,
sclc_file, output_folder, comp.x = "comp.1", components = 3,
threshold = 3)
|
tcga_location |
location of predicted files of tcga |
crpc_file |
location of predicted file of crpc |
nepc_file |
location of predicted file of nepc |
sclc_file |
location of predicted file of sclc |
output_folder |
the folder to output to, default is ./ i.e. current folder |
pattern |
pattern to grep for in files that have predictions |
pattern |
pattern to grep for in files that have predictions |
tcga_location |
location of predicted files of tcga |
crpc_file |
location of predicted file of crpc |
nepc_file |
location of predicted file of nepc |
sclc_file |
location of predicted file of sclc |
output_folder |
the folder to output to, default is ./ i.e. current folder |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.